@@ -1,9 +1,9 @@
 from __future__ import annotations
 
 from collections import ChainMap
-from typing import Any
 
 import ckan.plugins.toolkit as tk
+from ckan import model
 from ckan.logic import validate
 from ckan.plugins import get_plugin
 
@@ -24,41 +24,42 @@ def flake_create(context, data_dict):
         name (str, optional): name of the flake
         data (dict): flake's data
         parent_id (str, optional): ID of flake to extend
+        author_id (str, optional): author ID(can be set only by sysadmin)
         extras (dict): flake's extra details
 
     """
-
     tk.check_access("flakes_flake_create", context, data_dict)
 
-    sess = context["session"]
-    model = context["model"]
+    author_id = data_dict.pop("author_id", tk.missing)
 
-    user = model.User.get(context["user"])
-    if not user:
-        raise tk.NotAuthorized()
+    if author_id is not None:
+        if author_id is tk.missing:
+            author_id = context["user"]
+
+        author = model.User.get(author_id)
+        if not author:
+            raise tk.NotAuthorized()
+
+        author_id = author.id
+
+    sess = context["session"]
 
     if "parent_id" in data_dict:
-        parent = (
-            sess.query(Flake)
-            .filter_by(id=data_dict["parent_id"])
-            .one_or_none()
-        )
+        parent = sess.query(Flake).filter_by(id=data_dict["parent_id"]).one_or_none()
 
         if not parent:
             raise tk.ObjectNotFound()
 
-        if parent.author_id != user.id:
-            raise tk.ValidationError(
-                {"parent_id": ["Must be owned by the same user"]}
-            )
+        if parent.author_id != author_id:
+            raise tk.ValidationError({"parent_id": ["Must be owned by the same user"]})
 
     if (
         "name" in data_dict
-        and Flake.by_name(data_dict["name"], user.id).one_or_none()
+        and Flake.by_name(data_dict["name"], author_id).one_or_none()
     ):
         raise tk.ValidationError({"name": ["Must be unique"]})
 
-    flake = Flake(author_id=user.id, **data_dict)
+    flake = Flake(author_id=author_id, **data_dict)
     sess.add(flake)
     sess.commit()
 
@@ -79,9 +80,7 @@ def flake_show(context, data_dict):
     tk.check_access("flakes_flake_show", context, data_dict)
 
     sess = context["session"]
-    flake: Flake = (
-        sess.query(Flake).filter_by(id=data_dict["id"]).one_or_none()
-    )
+    flake: Flake = sess.query(Flake).filter_by(id=data_dict["id"]).one_or_none()
     if not flake:
         raise tk.ObjectNotFound()
 
@@ -113,26 +112,22 @@ def flake_list(context, data_dict):
 
     context["expand"] = data_dict["expand"]
 
-    if data_dict.get("global"):
-        user_id = None
+    author_id = data_dict.get("author_id", tk.missing)
 
-    elif "user" in data_dict:
-        user = context["model"].User.get(data_dict["user"])
+    if author_id is not None:
+        if author_id is tk.missing:
+            author_id = context["user"]
+
+        user = context["model"].User.get(author_id)
         if not user:
-            raise tk.ObjectNotFound()
-        user_id = user.id
-
-    else:
-        user = context["model"].User.get(context["user"])
-        user_id = user.id
+            raise tk.ObjectNotFound("User not found")
 
+        author_id = user.id
 
     if data_dict["extras"]:
-        flakes = Flake.by_extra(data_dict["extras"], user_id)
-    elif user_id:
-        flakes = user.flakes
+        flakes = Flake.by_extra(data_dict["extras"], author_id)
     else:
-        flakes = context["session"].query(Flake)
+        flakes = Flake.by_author(author_id)
 
     return [flake.dictize(context) for flake in flakes]
 
@@ -173,14 +168,12 @@ def flake_override(context, data_dict):
         name (str): Name flake to override
         data (dict): flakes data
         parent_id (str, optional): ID of flake to extend
+        author_id (str, optional): author ID(can be set only by sysadmin if flake does not exist)
         extras (dict): flake's extra details
     """
-
     tk.check_access("flakes_flake_override", context, data_dict)
     try:
-        flake = tk.get_action("flakes_flake_lookup")(
-            context.copy(), {"name": data_dict["name"]}
-        )
+        flake = tk.get_action("flakes_flake_lookup")(context.copy(), data_dict)
     except tk.ObjectNotFound:
         action = tk.get_action("flakes_flake_create")
     else:
@@ -221,14 +214,28 @@ def flake_lookup(context, data_dict):
 
     Args:
         name (str): Name of the flake
-    """
+        expand (bool, optional): Extend flake using data from the parent flakes
+        author_id (str, optional): author ID(can be set only by sysadmin)
 
+    """
     tk.check_access("flakes_flake_lookup", context, data_dict)
-    user = context["model"].User.get(context["user"])
-    flake = Flake.by_name(data_dict["name"], user.id).one_or_none()
+
+    author_id = data_dict.get("author_id", tk.missing)
+
+    if author_id is not None:
+        if author_id is tk.missing:
+            author_id = context["user"]
+
+        user = context["model"].User.get(author_id)
+        if not user:
+            raise tk.ObjectNotFound("User not found")
+
+        author_id = user.id
+
+    flake = Flake.by_name(data_dict["name"], author_id).one_or_none()
 
     if not flake:
-        raise tk.ObjectNotFound()
+        raise tk.ObjectNotFound("Flake not found")
 
     return flake.dictize(context)
 
