@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from ckan.logic.schema import validator_args
 
 
@@ -11,12 +13,14 @@ def flake_create(
     unicode_safe,
     flakes_flake_id_exists,
     ignore_empty,
+    empty_if_not_sysadmin,
 ):
     return {
         "name": [ignore_empty, unicode_safe],
         "data": [not_missing, convert_to_json_if_string, dict_only],
         "parent_id": [ignore_missing, flakes_flake_id_exists],
         "extras": [ignore_missing, convert_to_json_if_string, dict_only],
+        "author_id": [empty_if_not_sysadmin],
         "__extras": [ignore],
     }
 
@@ -42,8 +46,7 @@ def flake_update(
 
 @validator_args
 def flake_override(not_empty, unicode_safe):
-    schema = flake_update()
-    schema.pop("id")
+    schema = flake_create()
     schema["name"] = [not_empty, unicode_safe]
     return schema
 
@@ -73,18 +76,18 @@ def flake_list(
     ignore_missing,
 ):
     return {
-        "user": [empty_if_not_sysadmin, ignore_missing],
-        "global": [empty_if_not_sysadmin, boolean_validator],
+        "author_id": [empty_if_not_sysadmin],
         "expand": [boolean_validator],
         "extras": [default("{}"), convert_to_json_if_string, dict_only],
     }
 
 
 @validator_args
-def flake_lookup(boolean_validator, not_empty, unicode_safe):
+def flake_lookup(boolean_validator, not_empty, unicode_safe, empty_if_not_sysadmin):
     return {
         "name": [not_empty, unicode_safe],
         "expand": [boolean_validator],
+        "author_id": [empty_if_not_sysadmin],
     }
 
 
@@ -93,22 +96,24 @@ def flake_validate(boolean_validator, not_missing, unicode_safe):
     return {
         "id": [not_missing, unicode_safe],
         "expand": [boolean_validator],
-        "schema": [not_missing],
+        "schema": [not_missing, unicode_safe],
     }
 
 
 @validator_args
-def data_validate(convert_to_json_if_string, dict_only, not_missing):
+def data_validate(convert_to_json_if_string, dict_only, not_missing, unicode_safe):
     return {
         "data": [not_missing, convert_to_json_if_string, dict_only],
-        "schema": [not_missing],
+        "schema": [not_missing, unicode_safe],
     }
 
 
 @validator_args
-def data_example(not_missing, convert_to_json_if_string, dict_only, default):
+def data_example(
+    not_missing, convert_to_json_if_string, dict_only, default, unicode_safe
+):
     return {
-        "factory": [not_missing],
+        "factory": [not_missing, unicode_safe],
         "data": [default("{}"), convert_to_json_if_string, dict_only],
     }
 
@@ -140,10 +145,10 @@ def flake_combine(
 
 
 @validator_args
-def flake_merge(boolean_validator, ignore_missing):
+def flake_merge(boolean_validator, ignore_missing, unicode_safe):
     schema = flake_combine()
     schema["remove"] = [boolean_validator]
-    schema["destination"] = [ignore_missing]
+    schema["destination"] = [ignore_missing, unicode_safe]
     return schema
 
 
