@@ -2,23 +2,17 @@ from __future__ import annotations
 
 from collections import ChainMap
 from datetime import datetime
-from typing import Any, Iterable, Optional, TYPE_CHECKING
+from typing import TYPE_CHECKING, Any, Optional
 
 from flatten_dict import flatten
+from sqlalchemy import Column, DateTime, ForeignKey, UnicodeText, UniqueConstraint
+from sqlalchemy.dialects.postgresql import JSONB
+from sqlalchemy.orm import backref, relationship
+from typing_extensions import Self
 
 import ckan.model as model
 from ckan.lib.dictization import table_dictize
 from ckan.model.types import make_uuid
-from sqlalchemy import (
-    Column,
-    DateTime,
-    ForeignKey,
-    UnicodeText,
-    UniqueConstraint,
-)
-from sqlalchemy.dialects.postgresql import JSONB
-from sqlalchemy.orm import backref, relationship
-from typing_extensions import Self
 
 from .base import Base
 
@@ -32,28 +26,22 @@ class Flake(Base):
     id = Column(UnicodeText, primary_key=True, default=make_uuid)
     name: Optional[str] = Column(UnicodeText, unique=True, nullable=True)
     data: dict[str, Any] = Column(JSONB, nullable=False)
-    modified_at: datetime = Column(
-        DateTime, nullable=False, default=datetime.utcnow
-    )
-    author_id: str = Column(
+    modified_at: datetime = Column(DateTime, nullable=False, default=datetime.utcnow)
+    author_id: Optional[str] = Column(
         UnicodeText, ForeignKey(model.User.id), nullable=False
     )
-    parent_id: Optional[str] = Column(
-        UnicodeText, ForeignKey("flakes_flake.id")
-    )
+    parent_id: Optional[str] = Column(UnicodeText, ForeignKey("flakes_flake.id"))
     extras: dict[str, Any] = Column(JSONB, nullable=False, default=dict)
 
     UniqueConstraint(name, author_id)
 
     author = relationship(
         model.User,
-        backref=backref("flakes", cascade="all, delete-orphan"),
+        backref=backref("flakes", cascade="all, delete"),
     )
     parent = relationship(
         "Flake",
-        backref=backref(
-            "flakes", cascade="all, delete-orphan", single_parent=True
-        ),
+        backref=backref("flakes", cascade="all, delete-orphan", single_parent=True),
         remote_side=[id],
     )
 
@@ -79,24 +67,21 @@ class Flake(Base):
         return result
 
     @classmethod
-    def by_author(cls, author_id: str) -> "Query[Flake]":
+    def by_author(cls, author_id: Optional[str]) -> "Query[Self]":
         """Get user's flakes."""
         return model.Session.query(cls).filter_by(author_id=author_id)
 
     @classmethod
-    def by_name(cls, name: str, author_id: Optional[str]) -> "Query[Flake]":
+    def by_name(cls, name: str, author_id: Optional[str]) -> "Query[Self]":
         """Get user's flake using unique name of flake."""
-        q = model.Session.query(cls)
-
-        if author_id:
-            q = q.filter_by(name=name, author_id=author_id)
+        q = cls.by_author(author_id).filter_by(name=name)
 
         return q
 
     @classmethod
     def by_extra(
         cls, extras: dict[str, Any], author_id: Optional[str]
-    ) -> "Query[Flake]":
+    ) -> "Query[Self]":
         """Get user's flakes using extra attribute."""
         flattened = flatten(extras)
 
